"xconq*portholeLabel.Translations: #override \\n\
	~Shift<Btn1Down>: toolaction() \\n\
	 Shift<Btn1Down>: toolselection() \\n\
	~Shift<Btn2Down>: select() movelook() \\n\
	 Shift<Btn2Down>: select() \\n\
	 Shift<Btn2Up>:   distance() \\n\
	<Btn3Down>: select() moveunit() \\n\
	Meta<MotionNotify>:motionselect() movelook() \\n\
	<KeyPress>KP_7: movelook_ul() \\n\
	<KeyPress>KP_4: movelook_l() \\n\
	<KeyPress>KP_1: movelook_dl() \\n\
	<KeyPress>KP_9: movelook_ur() \\n\
	<KeyPress>KP_6: movelook_r() \\n\
	<KeyPress>KP_3: movelook_dr() \\n\
	<KeyPress>KP_5: center() \\n\
	<Expose>:   redraw() \\n\
	<KeyPress>: keypress() \\n",
"xconq*map*helpPop.label:		help",
"xconq*map*controlForm*top:			ChainTop",
"xconq*map*controlForm*bottom:		ChainTop",
"xconq*map*sides.top:			ChainTop",
"xconq*map*sides.bottom:			ChainTop",
"xconq*map*sides.left:			ChainLeft",
"xconq*map*sides.right:			ChainLeft",
"xconq*map*listView.top:			ChainTop",
"xconq*map*listView.bottom:		ChainBottom",
"xconq*map*listView.left:		ChainLeft",
"xconq*map*listView.right:		ChainLeft",
"xconq*map*panner.top:			ChainBottom",
"xconq*map*panner.bottom:		ChainBottom",
"xconq*map*panner.left:			ChainLeft",
"xconq*map*panner.right:			ChainLeft",
"xconq*map*panner.rubberBand:		true",
"xconq*helpShell.title:			xconq help",
"xconq*helpShell*topicPort.height:	300",
"xconq*helpShell*topicPort.width:	100",
"xconq*helpShell*title.width:		500",
"xconq*helpShell*title.borderWidth:	  0",
"xconq*helpShell*title.font:		-*-helvetica-bold-r-*-*-18-*-*-*-*-*-*-*",
"xconq*helpShell*text.height:		300",
"xconq*helpShell*text.width:		400",
"xconq*helpShell*topicList.font:		-*-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*helpShell*text*font:		7x13",
"xconq*PrintSetup.title:			xconq print setup",
"xconq*PrintSetup*Dialog*value:		0",
"xconq*PrintSetup*Dialog*value.translations: #override \\n\
	<Key>Return: DoPrintDialog()",
"xconq*PrintSetup*help.Label:		\\ help ",
"xconq*PrintSetup*print.Label:		\\ print ",
"xconq*PrintSetup*done.Label:		\\ done ",
"xconq*PrintSetup*names.label:		interesting names",
"xconq*PrintSetup*cellSize.label:	cell size",
"xconq*PrintSetup*gridSize.label:	grid thick.",
"xconq*PrintSetup*pageWidth.label:	page width",
"xconq*PrintSetup*pageHeight.label:	page height",
"xconq*PrintSetup*topMargin.label:	top margin",
"xconq*PrintSetup*bottomMargin.label:	bottom margin",
"xconq*PrintSetup*leftMargin.label:	left margin",
"xconq*PrintSetup*rightMargin.label:	right margin",
"xconq*PrintSetup*terrainGray.label:	terrain gray",
"xconq*PrintSetup*enemyGray.label:	enemy gray",
"xconq*PrintSetup*borderWidth.label:	border thick.",
"xconq*PrintSetup*connWidth.label:	conn thick.",
"xconq*PrintSetupHelp.title:		xconq print setup help",
"xconq*PrintSetupHelp*baseTranslations: #override \
	<Key>Return: DonePrintHelp() \\n\
	<Key>Escape: DonePrintHelp() ",
"xconq*PrintSetupHelp*helpDone.Label: \\ done ",
"xconq*map*ctrlpanelPop.label:		contr. panel",
"xconq*ctrlpanelPop*top:			ChainTop",
"xconq*ctrlpanelPop*bottom:		ChainTop",
"xconq*ctrlpanelPop*left:		ChainLeft",
"xconq*ctrlpanelPop*right:		ChainLeft",
"xconq*controlPanel.title: xconq control panel",
"xconq*controlPanel.form.popDown.label:	close",
"xconq*controlPanel.form.what.label: what should I draw in the map window?",
"xconq*controlPanel.form.monochrome.label: should I use black&white?",
"xconq*controlPanel.form.color.label: what should I use color images for?",
"xconq*controlPanel.form.what.vertDistance:	 4",
"xconq*controlPanel.form.Label.vertDistance:	12",
"xconq*controlPanel.form.Command.vertDistance:	12",
"xconq*gameDialog*font:		-adobe-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameDialog*Command.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameDialog*label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameDialog*name.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameDialog*name.width:		100",
"xconq*gameDialog*viewport.height:	604",
"xconq*gameDialog*label.label:		select a game",
"xconq*gameDialog.title: 		xconq game selection",
"xconq.gameDialog*inForm.Form.horizDistance:	0",
"xconq.gameDialog*inForm.Form*vertDistance:	0",
"xconq.gameDialog*inForm.Form.borderWidth:	0",
"xconq.gameDialog*inForm.intro.vertDistance:	4",
"xconq*gameForm*font:		-adobe-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm*name.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm*instructions_label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm*notes_label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm*variant.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm*assign.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm.Command.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm.Dialog.value*font:-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm*add.label:		add player",
"xconq*gameForm.pane*Text.width:		500",
"xconq*gameForm.pane*Text.height:		50",
"xconq*gameForm.pane*Text.scrollHorizontal:	whenNeeded",
"xconq*gameForm.pane*Text.scrollVertical:	whenNeeded",
"xconq*gameForm.pane.borderWidth:		0",
"xconq*gameForm.pane.horizDistance:	0",
"xconq*gameForm.varMessage.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm.nameMessage.font:-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*gameForm.idMessage.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*Scrollbar.Thickness:		10",
"xconq*Scrollbar.thumb:			None",
"xconq*ok.label:				\\ OK\\ ",
"xconq*cancel.label:			Cancel",
"xconq.unitCloseup*info.width:  		500",
"xconq.unitCloseup*info.height: 		300",
"xconq.unitCloseup*info*font:		7x13",
"xconq.unitCloseup*icon.height:		20",
"xconq.unitCloseup*label.height:		20",
"xconq.unitCloseup*flag.height:		20",
"xconq.unitCloseup*side.height:		20",
"xconq.unitCloseup*Label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.unitCloseup*Command.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.unitCloseup*update.label:		Update",
"xconq.unitCloseup*focus.label:		Focus",
"xconq.unitCloseup*close.label:		Close",
"xconq.sideCloseup*info.width:  			500",
"xconq.sideCloseup*info.height:	 		150",
"xconq.sideCloseup*info*font:			7x13",
"xconq.sideCloseup*flag.height:			20",
"xconq.sideCloseup*side.height:			20",
"xconq.sideCloseup*Label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.sideCloseup*Command.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.sideCloseup*update.label:			Update",
"xconq.sideCloseup*close.label:			Close",
"xconq.sideCloseup*filter.width: 		500",
"xconq.sideCloseup*filter.Toggle.height:		20",
"xconq.sideCloseup*filter.Label.height:		20",
"xconq.sideCloseup*filter.label.label:		Filter units:",
"xconq.sideCloseup*filter.allTypes.label:	all types",
"xconq.sideCloseup*filter.acpLeft.label:		ACP left",
"xconq.sideCloseup*listUnits.label:		list units",
"xconq.unitList*Label.height:			20",
"xconq.unitList*allTypes.label:			all types",
"xconq.unitList*acpLeft.label:			ACP left",
"xconq.unitList*failed.label:			\
no unit found matching filter criteria",
"xconq.unitList*list.forceColumns:		true",
"xconq.unitList*list.defaultColumns:		1",
"xconq.unitList*port.height:			300",
"xconq.unitList*port.width:			550",
"xconq.unitList*Label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.unitList*Command.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.closeupList.title:			xconq closeup list",
"xconq.closeupList.iconName:			xconq closeup list",
"xconq.closeupList*list.forceColumns:		true",
"xconq.closeupList*list.defaultColumns:		1",
"xconq.closeupList*port.height:			300",
"xconq.closeupList*port.width:			550",
"xconq.closeupList*Label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.unitCloseup*info.width:  		500",
"xconq.unitCloseup*info.height: 		300",
"xconq.unitCloseup*info*font:		7x13",
"xconq.unitCloseup*icon.height:		20",
"xconq.unitCloseup*label.height:		20",
"xconq.unitCloseup*flag.height:		20",
"xconq.unitCloseup*side.height:		20",
"xconq.unitCloseup*Label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.unitCloseup*Command.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.unitCloseup*update.label:		Update",
"xconq.unitCloseup*focus.label:		Focus",
"xconq.unitCloseup*close.label:		Close",
"xconq.sideCloseup*info.width:  			500",
"xconq.sideCloseup*info.height:	 		150",
"xconq.sideCloseup*info*font:			7x13",
"xconq.sideCloseup*flag.height:			20",
"xconq.sideCloseup*side.height:			20",
"xconq.sideCloseup*Label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.sideCloseup*Command.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.sideCloseup*update.label:			Update",
"xconq.sideCloseup*close.label:			Close",
"xconq.sideCloseup*filter.width: 		500",
"xconq.sideCloseup*filter.Toggle.height:		20",
"xconq.sideCloseup*filter.Label.height:		20",
"xconq.sideCloseup*filter.label.label:		Filter units:",
"xconq.sideCloseup*filter.allTypes.label:	all types",
"xconq.sideCloseup*filter.acpLeft.label:		ACP left",
"xconq.sideCloseup*listUnits.label:		list units",
"xconq.unitList*Label.height:			20",
"xconq.unitList*allTypes.label:			all types",
"xconq.unitList*acpLeft.label:			ACP left",
"xconq.unitList*failed.label:			\
no unit found matching filter criteria",
"xconq.unitList*list.forceColumns:		true",
"xconq.unitList*list.defaultColumns:		1",
"xconq.unitList*port.height:			300",
"xconq.unitList*port.width:			550",
"xconq.unitList*Label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.unitList*Command.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.closeupList.title:			xconq closeup list",
"xconq.closeupList.iconName:			xconq closeup list",
"xconq.closeupList*list.forceColumns:		true",
"xconq.closeupList*list.defaultColumns:		1",
"xconq.closeupList*port.height:			300",
"xconq.closeupList*port.width:			550",
"xconq.closeupList*Label.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.orders.title:				xconq standing orders",
"xconq.orders*port.height:			250",
"xconq.orders*port.width:			449",
"xconq.orders.form.?.font:	-adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.orders*orders.Form.vertDistance:		-1",
"xconq.orders*orders.Form.horizDistance:		-1",
"xconq.orders*orders.Form.?.height:		20",
"xconq.orders*orders.Form.toggle.width:		20",
"xconq.orders*orders.Form.width:			438",
"xconq.orders*orders.Form.height:		30",
"xconq.utypeSelect*box.width:			156",
"xconq.utypeSelect*box.Command.height:		20",
"xconq.utypeSelect*box.cancel.font: -adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.condSelect*box.Command.font: -adobe-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*",
"xconq.condSelect*box.cancel.font: -adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.taskSelect.box.width:			200",
"xconq.taskSelect*box.Command.font: -adobe-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*",
"xconq.taskSelect*box.cancel.font: -adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq.stringSelect*baseTranslations: #override \
	<Key>Return: DoneStringSelect()",
"xconq*ordersHelp.title:			xconq standing orders help",
"xconq*ordersHelp*Command.font:  -adobe-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
"xconq*ordersHelp*Label.font:    -adobe-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*",
"xconq*ordersHelp*baseTranslations: #override \
	<Key>Return: DoneOrdersHelp() \\n\
	<Key>Escape: DoneOrdersHelp() ",
